Class: Aws::MigrationHubRefactorSpaces::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MigrationHubRefactorSpaces::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-migrationhubrefactorspaces/client.rb,
sig/client.rbs
Overview
An API client for MigrationHubRefactorSpaces. To construct a client, you need to configure a :region and :credentials.
client = Aws::MigrationHubRefactorSpaces::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateApplicationResponseSuccess, _CreateEnvironmentResponseSuccess, _CreateRouteResponseSuccess, _CreateServiceResponseSuccess, _DeleteApplicationResponseSuccess, _DeleteEnvironmentResponseSuccess, _DeleteResourcePolicyResponseSuccess, _DeleteRouteResponseSuccess, _DeleteServiceResponseSuccess, _GetApplicationResponseSuccess, _GetEnvironmentResponseSuccess, _GetResourcePolicyResponseSuccess, _GetRouteResponseSuccess, _GetServiceResponseSuccess, _ListApplicationsResponseSuccess, _ListEnvironmentVpcsResponseSuccess, _ListEnvironmentsResponseSuccess, _ListRoutesResponseSuccess, _ListServicesResponseSuccess, _ListTagsForResourceResponseSuccess, _PutResourcePolicyResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateRouteResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces application.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces environment.
-
#create_route(params = {}) ⇒ Types::CreateRouteResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces route.
-
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces service.
-
#delete_application(params = {}) ⇒ Types::DeleteApplicationResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces application.
-
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces environment.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the resource policy set for the environment.
-
#delete_route(params = {}) ⇒ Types::DeleteRouteResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces route.
-
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces service.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces application.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces environment.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets the resource-based permission policy that is set for the given environment.
-
#get_route(params = {}) ⇒ Types::GetRouteResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces route.
-
#get_service(params = {}) ⇒ Types::GetServiceResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces service.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces applications within an environment.
-
#list_environment_vpcs(params = {}) ⇒ Types::ListEnvironmentVpcsResponse
Lists all Amazon Web Services Migration Hub Refactor Spaces service virtual private clouds (VPCs) that are part of the environment.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists Amazon Web Services Migration Hub Refactor Spaces environments owned by a caller account or shared with the caller account.
-
#list_routes(params = {}) ⇒ Types::ListRoutesResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces routes within an application.
-
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces services within an application.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags of a resource.
-
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based permission policy to the Amazon Web Services Migration Hub Refactor Spaces environment.
-
#tag_resource(params = {}) ⇒ Struct
Removes the tags of a given resource.
-
#untag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource.
-
#update_route(params = {}) ⇒ Types::UpdateRouteResponse
Updates an Amazon Web Services Migration Hub Refactor Spaces route.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2054 2055 2056 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 2054 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2057 2058 2059 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 2057 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 2027 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MigrationHubRefactorSpaces') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-migrationhubrefactorspaces' context[:gem_version] = '1.57.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces application. The account that owns the environment also owns the applications created inside the environment, regardless of the account that creates the application. Refactor Spaces provisions an Amazon API Gateway, API Gateway VPC link, and Network Load Balancer for the application proxy inside your account.
In environments created with a
CreateEnvironment:NetworkFabricType of NONE you need to
configure VPC to VPC connectivity between your service VPC and
the application proxy VPC to route traffic through the application
proxy to a service with a private URL endpoint. For more information,
see Create an application in the Refactor Spaces User Guide.
98 |
# File 'sig/client.rbs', line 98
def create_application: (
|
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces environment. The caller owns the environment resource, and all Refactor Spaces applications, services, and routes created within the environment. They are referred to as the environment owner. The environment owner has cross-account visibility and control of Refactor Spaces resources that are added to the environment by other accounts that the environment is shared with.
When creating an environment with a
CreateEnvironment:NetworkFabricType of TRANSIT_GATEWAY,
Refactor Spaces provisions a transit gateway to enable services in
VPCs to communicate directly across accounts. If
CreateEnvironment:NetworkFabricType is NONE, Refactor Spaces
does not create a transit gateway and you must use your network
infrastructure to route traffic to services with private URL
endpoints.
126 |
# File 'sig/client.rbs', line 126
def create_environment: (
|
#create_route(params = {}) ⇒ Types::CreateRouteResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces route.
The account owner of the service resource is always the environment
owner, regardless of which account creates the route. Routes target a
service in the application. If an application does not have any
routes, then the first route must be created as a DEFAULT
RouteType.
When created, the default route defaults to an active state so state is not a required input. However, like all other state values the state of the default route can be updated after creation, but only when all other routes are also inactive. Conversely, no route can be active without the default route also being active.
When you create a route, Refactor Spaces configures the Amazon API Gateway to send traffic to the target service as follows:
-
URL Endpoints
If the service has a URL endpoint, and the endpoint resolves to a private IP address, Refactor Spaces routes traffic using the API Gateway VPC link. If a service endpoint resolves to a public IP address, Refactor Spaces routes traffic over the public internet. Services can have HTTP or HTTPS URL endpoints. For HTTPS URLs, publicly-signed certificates are supported. Private Certificate Authorities (CAs) are permitted only if the CA's domain is also publicly resolvable.
Refactor Spaces automatically resolves the public Domain Name System (DNS) names that are set in
CreateService:UrlEndpointwhen you create a service. The DNS names resolve when the DNS time-to-live (TTL) expires, or every 60 seconds for TTLs less than 60 seconds. This periodic DNS resolution ensures that the route configuration remains up-to-date.One-time health check
A one-time health check is performed on the service when either the route is updated from inactive to active, or when it is created with an active state. If the health check fails, the route transitions the route state to
FAILED, an error code ofSERVICE_ENDPOINT_HEALTH_CHECK_FAILUREis provided, and no traffic is sent to the service.For private URLs, a target group is created on the Network Load Balancer and the load balancer target group runs default target health checks. By default, the health check is run against the service endpoint URL. Optionally, the health check can be performed against a different protocol, port, and/or path using the CreateService:UrlEndpoint parameter. All other health check settings for the load balancer use the default values described in the Health checks for your target groups in the Elastic Load Balancing guide. The health check is considered successful if at least one target within the target group transitions to a healthy state.
-
Lambda function endpoints
If the service has an Lambda function endpoint, then Refactor Spaces configures the Lambda function's resource policy to allow the application's API Gateway to invoke the function.
The Lambda function state is checked. If the function is not active, the function configuration is updated so that Lambda resources are provisioned. If the Lambda state is
Failed, then the route creation fails. For more information, see the GetFunctionConfiguration's State response parameter in the Lambda Developer Guide.A check is performed to determine that a Lambda function with the specified ARN exists. If it does not exist, the health check fails. For public URLs, a connection is opened to the public endpoint. If the URL is not reachable, the health check fails.
Environments without a network bridge
When you create environments without a network bridge
(CreateEnvironment:NetworkFabricType is NONE) and you use your
own networking infrastructure, you need to configure VPC to VPC
connectivity between your network and the application proxy VPC.
Route creation from the application proxy to service endpoints will
fail if your network is not configured to connect to the application
proxy VPC. For more information, see Create a route in the
Refactor Spaces User Guide.
151 |
# File 'sig/client.rbs', line 151
def create_route: (
|
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces service. The account owner of the service is always the environment owner, regardless of which account in the environment creates the service. Services have either a URL endpoint in a virtual private cloud (VPC), or a Lambda function endpoint.
If an Amazon Web Services resource is launched in a service VPC, and
you want it to be accessible to all of an environment’s services with
VPCs and routes, apply the RefactorSpacesSecurityGroup to the
resource. Alternatively, to add more cross-account constraints, apply
your own security group.
191 |
# File 'sig/client.rbs', line 191
def create_service: (
|
#delete_application(params = {}) ⇒ Types::DeleteApplicationResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces application. Before you can delete an application, you must first delete any services or routes within the application.
220 |
# File 'sig/client.rbs', line 220
def delete_application: (
|
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces environment. Before you can delete an environment, you must first delete any applications and services within the environment.
235 |
# File 'sig/client.rbs', line 235
def delete_environment: (
|
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the resource policy set for the environment.
244 |
# File 'sig/client.rbs', line 244
def delete_resource_policy: (
|
#delete_route(params = {}) ⇒ Types::DeleteRouteResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces route.
259 |
# File 'sig/client.rbs', line 259
def delete_route: (
|
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces service.
277 |
# File 'sig/client.rbs', line 277
def delete_service: (
|
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces application.
301 |
# File 'sig/client.rbs', line 301
def get_application: (
|
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces environment.
322 |
# File 'sig/client.rbs', line 322
def get_environment: (
|
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets the resource-based permission policy that is set for the given environment.
332 |
# File 'sig/client.rbs', line 332
def get_resource_policy: (
|
#get_route(params = {}) ⇒ Types::GetRouteResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces route.
358 |
# File 'sig/client.rbs', line 358
def get_route: (
|
#get_service(params = {}) ⇒ Types::GetServiceResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces service.
385 |
# File 'sig/client.rbs', line 385
def get_service: (
|
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces applications within an environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
398 |
# File 'sig/client.rbs', line 398
def list_applications: (
|
#list_environment_vpcs(params = {}) ⇒ Types::ListEnvironmentVpcsResponse
Lists all Amazon Web Services Migration Hub Refactor Spaces service virtual private clouds (VPCs) that are part of the environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
411 |
# File 'sig/client.rbs', line 411
def list_environment_vpcs: (
|
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists Amazon Web Services Migration Hub Refactor Spaces environments owned by a caller account or shared with the caller account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
424 |
# File 'sig/client.rbs', line 424
def list_environments: (
|
#list_routes(params = {}) ⇒ Types::ListRoutesResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces routes within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
436 |
# File 'sig/client.rbs', line 436
def list_routes: (
|
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces services within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
450 |
# File 'sig/client.rbs', line 450
def list_services: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags of a resource. The caller account must be the same as
the resource’s OwnerAccountId. Listing tags in other accounts is not
supported.
463 |
# File 'sig/client.rbs', line 463
def list_tags_for_resource: (
|
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based permission policy to the Amazon Web Services
Migration Hub Refactor Spaces environment. The policy must contain the
same actions and condition statements as the
arn:aws:ram::aws:permission/AWSRAMDefaultPermissionRefactorSpacesEnvironment
permission in Resource Access Manager. The policy must not contain new
lines or blank lines.
472 |
# File 'sig/client.rbs', line 472
def put_resource_policy: (
|
#tag_resource(params = {}) ⇒ Struct
Removes the tags of a given resource. Tags are metadata which can be
used to manage a resource. To tag a resource, the caller account must
be the same as the resource’s OwnerAccountId. Tagging resources in
other accounts is not supported.
482 |
# File 'sig/client.rbs', line 482
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource. Tags are metadata
which can be used to manage a resource. To untag a resource, the
caller account must be the same as the resource’s OwnerAccountId.
Untagging resources across accounts is not supported.
492 |
# File 'sig/client.rbs', line 492
def untag_resource: (
|
#update_route(params = {}) ⇒ Types::UpdateRouteResponse
Updates an Amazon Web Services Migration Hub Refactor Spaces route.
508 |
# File 'sig/client.rbs', line 508
def update_route: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2047 2048 2049 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 2047 def waiter_names [] end |