Class: Aws::MigrationHubRefactorSpaces::Types::UriPathRouteInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MigrationHubRefactorSpaces::Types::UriPathRouteInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-migrationhubrefactorspaces/types.rb
Overview
The configuration for the URI path route type.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activation_state ⇒ String
If set to
ACTIVE, traffic is forwarded to this route’s service after the route is created. -
#append_source_path ⇒ Boolean
If set to
true, this option appends the source path to the service URL endpoint. -
#include_child_paths ⇒ Boolean
Indicates whether to match all subpaths of the given source path.
-
#methods ⇒ Array<String>
A list of HTTP methods to match.
-
#source_path ⇒ String
This is the path that Refactor Spaces uses to match traffic.
Instance Attribute Details
#activation_state ⇒ String
If set to ACTIVE, traffic is forwarded to this route’s service after the route is created.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/types.rb', line 2427 class UriPathRouteInput < Struct.new( :activation_state, :append_source_path, :include_child_paths, :methods, :source_path) SENSITIVE = [] include Aws::Structure end |
#append_source_path ⇒ Boolean
If set to true, this option appends the source path to the service URL endpoint.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/types.rb', line 2427 class UriPathRouteInput < Struct.new( :activation_state, :append_source_path, :include_child_paths, :methods, :source_path) SENSITIVE = [] include Aws::Structure end |
#include_child_paths ⇒ Boolean
Indicates whether to match all subpaths of the given source path. If this value is false, requests must match the source path exactly before they are forwarded to this route’s service.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/types.rb', line 2427 class UriPathRouteInput < Struct.new( :activation_state, :append_source_path, :include_child_paths, :methods, :source_path) SENSITIVE = [] include Aws::Structure end |
#methods ⇒ Array<String>
A list of HTTP methods to match. An empty list matches all values. If a method is present, only HTTP requests using that method are forwarded to this route’s service.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/types.rb', line 2427 class UriPathRouteInput < Struct.new( :activation_state, :append_source_path, :include_child_paths, :methods, :source_path) SENSITIVE = [] include Aws::Structure end |
#source_path ⇒ String
This is the path that Refactor Spaces uses to match traffic. Paths must start with / and are relative to the base of the application. To use path parameters in the source path, add a variable in curly braces. For example, the resource path user represents a path parameter called ‘user’.
2427 2428 2429 2430 2431 2432 2433 2434 2435 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/types.rb', line 2427 class UriPathRouteInput < Struct.new( :activation_state, :append_source_path, :include_child_paths, :methods, :source_path) SENSITIVE = [] include Aws::Structure end |