Class: Aws::MigrationHubRefactorSpaces::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MigrationHubRefactorSpaces::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-migrationhubrefactorspaces/client.rb
Overview
An API client for MigrationHubRefactorSpaces. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MigrationHubRefactorSpaces::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces application.
-
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces environment.
-
#create_route(params = {}) ⇒ Types::CreateRouteResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces route.
-
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces service.
-
#delete_application(params = {}) ⇒ Types::DeleteApplicationResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces application.
-
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces environment.
-
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the resource policy set for the environment.
-
#delete_route(params = {}) ⇒ Types::DeleteRouteResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces route.
-
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces service.
-
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces application.
-
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces environment.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets the resource-based permission policy that is set for the given environment.
-
#get_route(params = {}) ⇒ Types::GetRouteResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces route.
-
#get_service(params = {}) ⇒ Types::GetServiceResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces service.
-
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces applications within an environment.
-
#list_environment_vpcs(params = {}) ⇒ Types::ListEnvironmentVpcsResponse
Lists all Amazon Web Services Migration Hub Refactor Spaces service virtual private clouds (VPCs) that are part of the environment.
-
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists Amazon Web Services Migration Hub Refactor Spaces environments owned by a caller account or shared with the caller account.
-
#list_routes(params = {}) ⇒ Types::ListRoutesResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces routes within an application.
-
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces services within an application.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags of a resource.
-
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based permission policy to the Amazon Web Services Migration Hub Refactor Spaces environment.
-
#tag_resource(params = {}) ⇒ Struct
Removes the tags of a given resource.
-
#untag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource.
-
#update_route(params = {}) ⇒ Types::UpdateRouteResponse
Updates an Amazon Web Services Migration Hub Refactor Spaces route.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2054 2055 2056 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 2054 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2057 2058 2059 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 2057 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2027 2028 2029 2030 2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 2041 2042 2043 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 2027 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MigrationHubRefactorSpaces') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-migrationhubrefactorspaces' context[:gem_version] = '1.55.0' Seahorse::Client::Request.new(handlers, context) end |
#create_application(params = {}) ⇒ Types::CreateApplicationResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces application. The account that owns the environment also owns the applications created inside the environment, regardless of the account that creates the application. Refactor Spaces provisions an Amazon API Gateway, API Gateway VPC link, and Network Load Balancer for the application proxy inside your account.
In environments created with a
- CreateEnvironment:NetworkFabricType][1
-
of ‘NONE` you need to
configure [ VPC to VPC connectivity] between your service VPC and the application proxy VPC to route traffic through the application proxy to a service with a private URL endpoint. For more information, see [ Create an application] in the *Refactor Spaces User Guide*.
[1]: docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateEnvironment.html#migrationhubrefactorspaces-CreateEnvironment-request-NetworkFabricType [2]: docs.aws.amazon.com/whitepapers/latest/aws-vpc-connectivity-options/amazon-vpc-to-amazon-vpc-connectivity-options.html [3]: docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/getting-started-create-application.html
580 581 582 583 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 580 def create_application(params = {}, = {}) req = build_request(:create_application, params) req.send_request() end |
#create_environment(params = {}) ⇒ Types::CreateEnvironmentResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces environment. The caller owns the environment resource, and all Refactor Spaces applications, services, and routes created within the environment. They are referred to as the *environment owner*. The environment owner has cross-account visibility and control of Refactor Spaces resources that are added to the environment by other accounts that the environment is shared with.
When creating an environment with a
- CreateEnvironment:NetworkFabricType][1
-
of ‘TRANSIT_GATEWAY`,
Refactor Spaces provisions a transit gateway to enable services in VPCs to communicate directly across accounts. If
- CreateEnvironment:NetworkFabricType][1
-
is ‘NONE`, Refactor Spaces
does not create a transit gateway and you must use your network infrastructure to route traffic to services with private URL endpoints.
670 671 672 673 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 670 def create_environment(params = {}, = {}) req = build_request(:create_environment, params) req.send_request() end |
#create_route(params = {}) ⇒ Types::CreateRouteResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces route. The account owner of the service resource is always the environment owner, regardless of which account creates the route. Routes target a service in the application. If an application does not have any routes, then the first route must be created as a ‘DEFAULT` `RouteType`.
When created, the default route defaults to an active state so state is not a required input. However, like all other state values the state of the default route can be updated after creation, but only when all other routes are also inactive. Conversely, no route can be active without the default route also being active.
When you create a route, Refactor Spaces configures the Amazon API Gateway to send traffic to the target service as follows:
-
**URL Endpoints**
If the service has a URL endpoint, and the endpoint resolves to a private IP address, Refactor Spaces routes traffic using the API Gateway VPC link. If a service endpoint resolves to a public IP address, Refactor Spaces routes traffic over the public internet. Services can have HTTP or HTTPS URL endpoints. For HTTPS URLs, publicly-signed certificates are supported. Private Certificate Authorities (CAs) are permitted only if the CA’s domain is also publicly resolvable.
Refactor Spaces automatically resolves the public Domain Name System (DNS) names that are set in ‘CreateService:UrlEndpoint `when you create a service. The DNS names resolve when the DNS time-to-live (TTL) expires, or every 60 seconds for TTLs less than 60 seconds. This periodic DNS resolution ensures that the route configuration remains up-to-date.
**One-time health check**
A one-time health check is performed on the service when either the route is updated from inactive to active, or when it is created with an active state. If the health check fails, the route transitions the route state to ‘FAILED`, an error code of `SERVICE_ENDPOINT_HEALTH_CHECK_FAILURE` is provided, and no traffic is sent to the service.
For private URLs, a target group is created on the Network Load Balancer and the load balancer target group runs default target health checks. By default, the health check is run against the service endpoint URL. Optionally, the health check can be performed against a different protocol, port, and/or path using the
- CreateService:UrlEndpoint][1
-
parameter. All other health check
settings for the load balancer use the default values described in the [Health checks for your target groups] in the *Elastic Load Balancing guide*. The health check is considered successful if at least one target within the target group transitions to a healthy state.
-
**Lambda function endpoints**
If the service has an Lambda function endpoint, then Refactor Spaces configures the Lambda function’s resource policy to allow the application’s API Gateway to invoke the function.
The Lambda function state is checked. If the function is not active, the function configuration is updated so that Lambda resources are provisioned. If the Lambda state is ‘Failed`, then the route creation fails. For more information, see the
- GetFunctionConfiguration’s State response parameter][3
-
in the
*Lambda Developer Guide*.
A check is performed to determine that a Lambda function with the specified ARN exists. If it does not exist, the health check fails. For public URLs, a connection is opened to the public endpoint. If the URL is not reachable, the health check fails.
**Environments without a network bridge**
When you create environments without a network bridge ([CreateEnvironment:NetworkFabricType] is ‘NONE)` and you use your own networking infrastructure, you need to configure [VPC to VPC connectivity] between your network and the application proxy VPC. Route creation from the application proxy to service endpoints will fail if your network is not configured to connect to the application proxy VPC. For more information, see [ Create a route] in the *Refactor Spaces User Guide*.
[1]: docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateService.html#migrationhubrefactorspaces-CreateService-request-UrlEndpoint [2]: docs.aws.amazon.com/elasticloadbalancing/latest/application/target-group-health-checks.html [3]: docs.aws.amazon.com/lambda/latest/dg/API_GetFunctionConfiguration.html#SSS-GetFunctionConfiguration-response-State [4]: docs.aws.amazon.com/migrationhub-refactor-spaces/latest/APIReference/API_CreateEnvironment.html#migrationhubrefactorspaces-CreateEnvironment-request-NetworkFabricType [5]: docs.aws.amazon.com/whitepapers/latest/aws-vpc-connectivity-options/amazon-vpc-to-amazon-vpc-connectivity-options.html [6]: docs.aws.amazon.com/migrationhub-refactor-spaces/latest/userguide/getting-started-create-role.html
871 872 873 874 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 871 def create_route(params = {}, = {}) req = build_request(:create_route, params) req.send_request() end |
#create_service(params = {}) ⇒ Types::CreateServiceResponse
Creates an Amazon Web Services Migration Hub Refactor Spaces service. The account owner of the service is always the environment owner, regardless of which account in the environment creates the service. Services have either a URL endpoint in a virtual private cloud (VPC), or a Lambda function endpoint.
If an Amazon Web Services resource is launched in a service VPC, and you want it to be accessible to all of an environment’s services with VPCs and routes, apply the ‘RefactorSpacesSecurityGroup` to the resource. Alternatively, to add more cross-account constraints, apply your own security group.
995 996 997 998 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 995 def create_service(params = {}, = {}) req = build_request(:create_service, params) req.send_request() end |
#delete_application(params = {}) ⇒ Types::DeleteApplicationResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces application. Before you can delete an application, you must first delete any services or routes within the application.
1039 1040 1041 1042 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1039 def delete_application(params = {}, = {}) req = build_request(:delete_application, params) req.send_request() end |
#delete_environment(params = {}) ⇒ Types::DeleteEnvironmentResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces environment. Before you can delete an environment, you must first delete any applications and services within the environment.
1077 1078 1079 1080 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1077 def delete_environment(params = {}, = {}) req = build_request(:delete_environment, params) req.send_request() end |
#delete_resource_policy(params = {}) ⇒ Struct
Deletes the resource policy set for the environment.
1099 1100 1101 1102 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1099 def delete_resource_policy(params = {}, = {}) req = build_request(:delete_resource_policy, params) req.send_request() end |
#delete_route(params = {}) ⇒ Types::DeleteRouteResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces route.
1145 1146 1147 1148 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1145 def delete_route(params = {}, = {}) req = build_request(:delete_route, params) req.send_request() end |
#delete_service(params = {}) ⇒ Types::DeleteServiceResponse
Deletes an Amazon Web Services Migration Hub Refactor Spaces service.
1199 1200 1201 1202 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1199 def delete_service(params = {}, = {}) req = build_request(:delete_service, params) req.send_request() end |
#get_application(params = {}) ⇒ Types::GetApplicationResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces application.
1270 1271 1272 1273 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1270 def get_application(params = {}, = {}) req = build_request(:get_application, params) req.send_request() end |
#get_environment(params = {}) ⇒ Types::GetEnvironmentResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces environment.
1327 1328 1329 1330 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1327 def get_environment(params = {}, = {}) req = build_request(:get_environment, params) req.send_request() end |
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Gets the resource-based permission policy that is set for the given environment.
1357 1358 1359 1360 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1357 def get_resource_policy(params = {}, = {}) req = build_request(:get_resource_policy, params) req.send_request() end |
#get_route(params = {}) ⇒ Types::GetRouteResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces route.
1436 1437 1438 1439 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1436 def get_route(params = {}, = {}) req = build_request(:get_route, params) req.send_request() end |
#get_service(params = {}) ⇒ Types::GetServiceResponse
Gets an Amazon Web Services Migration Hub Refactor Spaces service.
1512 1513 1514 1515 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1512 def get_service(params = {}, = {}) req = build_request(:get_service, params) req.send_request() end |
#list_applications(params = {}) ⇒ Types::ListApplicationsResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces applications within an environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1582 1583 1584 1585 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1582 def list_applications(params = {}, = {}) req = build_request(:list_applications, params) req.send_request() end |
#list_environment_vpcs(params = {}) ⇒ Types::ListEnvironmentVpcsResponse
Lists all Amazon Web Services Migration Hub Refactor Spaces service virtual private clouds (VPCs) that are part of the environment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1633 1634 1635 1636 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1633 def list_environment_vpcs(params = {}, = {}) req = build_request(:list_environment_vpcs, params) req.send_request() end |
#list_environments(params = {}) ⇒ Types::ListEnvironmentsResponse
Lists Amazon Web Services Migration Hub Refactor Spaces environments owned by a caller account or shared with the caller account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1691 1692 1693 1694 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1691 def list_environments(params = {}, = {}) req = build_request(:list_environments, params) req.send_request() end |
#list_routes(params = {}) ⇒ Types::ListRoutesResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces routes within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1765 1766 1767 1768 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1765 def list_routes(params = {}, = {}) req = build_request(:list_routes, params) req.send_request() end |
#list_services(params = {}) ⇒ Types::ListServicesResponse
Lists all the Amazon Web Services Migration Hub Refactor Spaces services within an application.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1837 1838 1839 1840 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1837 def list_services(params = {}, = {}) req = build_request(:list_services, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags of a resource. The caller account must be the same as the resource’s ‘OwnerAccountId`. Listing tags in other accounts is not supported.
1868 1869 1870 1871 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1868 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_resource_policy(params = {}) ⇒ Struct
Attaches a resource-based permission policy to the Amazon Web Services Migration Hub Refactor Spaces environment. The policy must contain the same actions and condition statements as the ‘arn:aws:ram::aws:permission/AWSRAMDefaultPermissionRefactorSpacesEnvironment` permission in Resource Access Manager. The policy must not contain new lines or blank lines.
1901 1902 1903 1904 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1901 def put_resource_policy(params = {}, = {}) req = build_request(:put_resource_policy, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Removes the tags of a given resource. Tags are metadata which can be used to manage a resource. To tag a resource, the caller account must be the same as the resource’s ‘OwnerAccountId`. Tagging resources in other accounts is not supported.
<note markdown=“1”> Amazon Web Services Migration Hub Refactor Spaces does not propagate tags to orchestrated resources, such as an environment’s transit gateway.
</note>
1938 1939 1940 1941 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1938 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Adds to or modifies the tags of the given resource. Tags are metadata which can be used to manage a resource. To untag a resource, the caller account must be the same as the resource’s ‘OwnerAccountId`. Untagging resources across accounts is not supported.
1967 1968 1969 1970 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 1967 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_route(params = {}) ⇒ Types::UpdateRouteResponse
Updates an Amazon Web Services Migration Hub Refactor Spaces route.
2018 2019 2020 2021 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 2018 def update_route(params = {}, = {}) req = build_request(:update_route, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2047 2048 2049 |
# File 'lib/aws-sdk-migrationhubrefactorspaces/client.rb', line 2047 def waiter_names [] end |